@@ -339,8 +339,8 @@ use PDL::Graphics::ColorSpace;
 use Carp;
 
 our @ISA = ( 'Exporter', 'PDL::Transform' );
-our $VERSION = '1.008';
-$VERSION = eval $VERSION;
+our $VERSION = '1.009';
+$VERSION =~ tr/_//d;
 
 our @EXPORT_OK = qw/ t_gamma t_brgb t_srgb t_shift_illuminant t_shift_rgb t_cmyk t_rgi t_cieXYZ t_xyz t_xyY t_xyy t_lab t_xyz2lab t_hsl t_hsv t_pc t_pcp/;
 our @EXPORT = @EXPORT_OK;
@@ -521,7 +521,7 @@ sub t_brgb {
 	$out;
     };
 
-    return gammify($me);
+    gammify($me);
 }
 
 =head2 t_srgb
